/*****************************************************************************
 * Stataload_NEDS_2015Q1Q3_IP.Do
 * This program will load the NEDS 2015 Q1Q3 IP csv File into Stata.
 * Because Stata loads the entire file into memory, it may not be possible
 * to load every data element for large files.  If necessary, edit this
 * program to change the memory size or to load only selected data elements.
 * The Stata INFILE command with the _SKIP option is used to select a subset of variables.
 * _skip (N) tells Stata to skip the next consecutive N variables.
 * Also can use "in" option after "using NEDS_2015Q1Q3_IP.csv" to read subset of the data.
 *****************************************************************************/

#delimit ;

/* Set available memory size */
set mem 1400m;

/* Read data elements from the csv file */
infile
      int    chron1
      int    chron2
      int    chron3
      int    chron4
      int    chron5
      int    chron6
      int    chron7
      int    chron8
      int    chron9
      int    chron10
      int    chron11
      int    chron12
      int    chron13
      int    chron14
      int    chron15
      int    chron16
      int    chron17
      int    chron18
      int    chron19
      int    chron20
      int    chron21
      int    chron22
      int    chron23
      int    chron24
      int    chron25
      int    chron26
      int    chron27
      int    chron28
      int    chron29
      int    chron30
      byte   disp_ip
      int    drg
      byte   drgver
      int    drg_nopoa
      str7   dx1
      str7   dx2
      str7   dx3
      str7   dx4
      str7   dx5
      str7   dx6
      str7   dx7
      str7   dx8
      str7   dx9
      str7   dx10
      str7   dx11
      str7   dx12
      str7   dx13
      str7   dx14
      str7   dx15
      str7   dx16
      str7   dx17
      str7   dx18
      str7   dx19
      str7   dx20
      str7   dx21
      str7   dx22
      str7   dx23
      str7   dx24
      str7   dx25
      str7   dx26
      str7   dx27
      str7   dx28
      str7   dx29
      str7   dx30
      int    dxccs1
      int    dxccs2
      int    dxccs3
      int    dxccs4
      int    dxccs5
      int    dxccs6
      int    dxccs7
      int    dxccs8
      int    dxccs9
      int    dxccs10
      int    dxccs11
      int    dxccs12
      int    dxccs13
      int    dxccs14
      int    dxccs15
      int    dxccs16
      int    dxccs17
      int    dxccs18
      int    dxccs19
      int    dxccs20
      int    dxccs21
      int    dxccs22
      int    dxccs23
      int    dxccs24
      int    dxccs25
      int    dxccs26
      int    dxccs27
      int    dxccs28
      int    dxccs29
      int    dxccs30
      byte   dxver
      str7   ecode1
      str7   ecode2
      str7   ecode3
      str7   ecode4
      int    e_ccs1
      int    e_ccs2
      int    e_ccs3
      int    e_ccs4
      str4   hcupfile
      long   hosp_ed
      byte   injury
      byte   injury_cut
      byte   injury_drown
      byte   injury_fall
      byte   injury_fire
      byte   injury_firearm
      byte   injury_machinery
      byte   injury_mvt
      byte   injury_nature
      byte   injury_poison
      byte   injury_severity
      byte   injury_struck
      byte   injury_suffocation
      byte   intent_assault
      byte   intent_self_harm
      byte   intent_unintentional
      double key_ed
      long   los_ip
      byte   mdc
      byte   mdc_nopoa
      byte   multinjury
      int    ndx
      int    necode
      int    npr_ip
      int    pclass_ip1
      int    pclass_ip2
      int    pclass_ip3
      int    pclass_ip4
      int    pclass_ip5
      int    pclass_ip6
      int    pclass_ip7
      int    pclass_ip8
      int    pclass_ip9
      int    prccs_ip1
      int    prccs_ip2
      int    prccs_ip3
      int    prccs_ip4
      int    prccs_ip5
      int    prccs_ip6
      int    prccs_ip7
      int    prccs_ip8
      int    prccs_ip9
      byte   prver
      str7   pr_ip1
      str7   pr_ip2
      str7   pr_ip3
      str7   pr_ip4
      str7   pr_ip5
      str7   pr_ip6
      str7   pr_ip7
      str7   pr_ip8
      str7   pr_ip9
      double totchg_ip
using NEDS_2015Q1Q3_IP.csv;

/*  Assign labels to the data elements */
label var chron1                   "Chronic condition indicator 1" ;
label var chron2                   "Chronic condition indicator 2" ;
label var chron3                   "Chronic condition indicator 3" ;
label var chron4                   "Chronic condition indicator 4" ;
label var chron5                   "Chronic condition indicator 5" ;
label var chron6                   "Chronic condition indicator 6" ;
label var chron7                   "Chronic condition indicator 7" ;
label var chron8                   "Chronic condition indicator 8" ;
label var chron9                   "Chronic condition indicator 9" ;
label var chron10                  "Chronic condition indicator 10" ;
label var chron11                  "Chronic condition indicator 11" ;
label var chron12                  "Chronic condition indicator 12" ;
label var chron13                  "Chronic condition indicator 13" ;
label var chron14                  "Chronic condition indicator 14" ;
label var chron15                  "Chronic condition indicator 15" ;
label var chron16                  "Chronic condition indicator 16" ;
label var chron17                  "Chronic condition indicator 17" ;
label var chron18                  "Chronic condition indicator 18" ;
label var chron19                  "Chronic condition indicator 19" ;
label var chron20                  "Chronic condition indicator 20" ;
label var chron21                  "Chronic condition indicator 21" ;
label var chron22                  "Chronic condition indicator 22" ;
label var chron23                  "Chronic condition indicator 23" ;
label var chron24                  "Chronic condition indicator 24" ;
label var chron25                  "Chronic condition indicator 25" ;
label var chron26                  "Chronic condition indicator 26" ;
label var chron27                  "Chronic condition indicator 27" ;
label var chron28                  "Chronic condition indicator 28" ;
label var chron29                  "Chronic condition indicator 29" ;
label var chron30                  "Chronic condition indicator 30" ;
label var disp_ip                  "Disposition of patient (uniform) from IP" ;
label var drg                      "DRG in effect on discharge date" ;
label var drgver                   "DRG grouper version used on discharge date" ;
label var drg_nopoa                "DRG in use on discharge date, calculated without POA" ;
label var dx1                      "Diagnosis 1" ;
label var dx2                      "Diagnosis 2" ;
label var dx3                      "Diagnosis 3" ;
label var dx4                      "Diagnosis 4" ;
label var dx5                      "Diagnosis 5" ;
label var dx6                      "Diagnosis 6" ;
label var dx7                      "Diagnosis 7" ;
label var dx8                      "Diagnosis 8" ;
label var dx9                      "Diagnosis 9" ;
label var dx10                     "Diagnosis 10" ;
label var dx11                     "Diagnosis 11" ;
label var dx12                     "Diagnosis 12" ;
label var dx13                     "Diagnosis 13" ;
label var dx14                     "Diagnosis 14" ;
label var dx15                     "Diagnosis 15" ;
label var dx16                     "Diagnosis 16" ;
label var dx17                     "Diagnosis 17" ;
label var dx18                     "Diagnosis 18" ;
label var dx19                     "Diagnosis 19" ;
label var dx20                     "Diagnosis 20" ;
label var dx21                     "Diagnosis 21" ;
label var dx22                     "Diagnosis 22" ;
label var dx23                     "Diagnosis 23" ;
label var dx24                     "Diagnosis 24" ;
label var dx25                     "Diagnosis 25" ;
label var dx26                     "Diagnosis 26" ;
label var dx27                     "Diagnosis 27" ;
label var dx28                     "Diagnosis 28" ;
label var dx29                     "Diagnosis 29" ;
label var dx30                     "Diagnosis 30" ;
label var dxccs1                   "CCS: diagnosis 1" ;
label var dxccs2                   "CCS: diagnosis 2" ;
label var dxccs3                   "CCS: diagnosis 3" ;
label var dxccs4                   "CCS: diagnosis 4" ;
label var dxccs5                   "CCS: diagnosis 5" ;
label var dxccs6                   "CCS: diagnosis 6" ;
label var dxccs7                   "CCS: diagnosis 7" ;
label var dxccs8                   "CCS: diagnosis 8" ;
label var dxccs9                   "CCS: diagnosis 9" ;
label var dxccs10                  "CCS: diagnosis 10" ;
label var dxccs11                  "CCS: diagnosis 11" ;
label var dxccs12                  "CCS: diagnosis 12" ;
label var dxccs13                  "CCS: diagnosis 13" ;
label var dxccs14                  "CCS: diagnosis 14" ;
label var dxccs15                  "CCS: diagnosis 15" ;
label var dxccs16                  "CCS: diagnosis 16" ;
label var dxccs17                  "CCS: diagnosis 17" ;
label var dxccs18                  "CCS: diagnosis 18" ;
label var dxccs19                  "CCS: diagnosis 19" ;
label var dxccs20                  "CCS: diagnosis 20" ;
label var dxccs21                  "CCS: diagnosis 21" ;
label var dxccs22                  "CCS: diagnosis 22" ;
label var dxccs23                  "CCS: diagnosis 23" ;
label var dxccs24                  "CCS: diagnosis 24" ;
label var dxccs25                  "CCS: diagnosis 25" ;
label var dxccs26                  "CCS: diagnosis 26" ;
label var dxccs27                  "CCS: diagnosis 27" ;
label var dxccs28                  "CCS: diagnosis 28" ;
label var dxccs29                  "CCS: diagnosis 29" ;
label var dxccs30                  "CCS: diagnosis 30" ;
label var dxver                    "Diagnosis Version" ;
label var ecode1                   "E code 1" ;
label var ecode2                   "E code 2" ;
label var ecode3                   "E code 3" ;
label var ecode4                   "E code 4" ;
label var e_ccs1                   "CCS: E Code 1" ;
label var e_ccs2                   "CCS: E Code 2" ;
label var e_ccs3                   "CCS: E Code 3" ;
label var e_ccs4                   "CCS: E Code 4" ;
label var hcupfile                 "Source of HCUP Record (SID or SEDD)" ;
label var hosp_ed                  "HCUP ED hospital identifier" ;
label var injury                   "Injury diagnosis reported on record (1:DX1 is an injury; 2:DX2+ is an injury; 0:No injury)" ;
label var injury_cut               "Injury by cutting or piercing (by E codes)" ;
label var injury_drown             "Injury by drowning or submersion (by E codes)" ;
label var injury_fall              "Injury by falling (by E codes)" ;
label var injury_fire              "Injury by fire, flame or hot object (by E codes)" ;
label var injury_firearm           "Injury by firearm (by E codes)" ;
label var injury_machinery         "Injury by machinery (by E codes)" ;
label var injury_mvt               "Injury involving motor vehicle traffic (by E codes)" ;
label var injury_nature            "Injury involving nature or environmental factors (by E codes)" ;
label var injury_poison            "Injury by poison (by E codes)" ;
label var injury_severity          "Injury severity score assigned by ICDPIC Stata program" ;
label var injury_struck            "Injury from being struck by or against (by E codes)" ;
label var injury_suffocation       "Injury by suffocation (by E codes)" ;
label var intent_assault           "Injury by assault indicated on the record (by E codes)" ;
label var intent_self_harm         "Intentional self harm indicated on the record (by diagnosis and/or E codes)" ;
label var intent_unintentional     "Unintentional injury indicated on the record (by E codes)" ;
label var key_ed                   "HCUP NEDS record identifier" ;
label var los_ip                   "Length of stay (cleaned) from IP" ;
label var mdc                      "MDC in effect on discharge date" ;
label var mdc_nopoa                "MDC in use on discharge date, calculated without POA" ;
label var multinjury               "More than one injury diagnosis reported on record" ;
label var ndx                      "Number of diagnoses on this record" ;
label var necode                   "Number of E codes on this record" ;
label var npr_ip                   "Number of procedures from inpatient discharge record" ;
label var pclass_ip1               "Principal procedure class for inpatient procedure" ;
label var pclass_ip2               "Procedure class 2 for inpatient procedure" ;
label var pclass_ip3               "Procedure class 3 for inpatient procedure" ;
label var pclass_ip4               "Procedure class 4 for inpatient procedure" ;
label var pclass_ip5               "Procedure class 5 for inpatient procedure" ;
label var pclass_ip6               "Procedure class 6 for inpatient procedure" ;
label var pclass_ip7               "Procedure class 7 for inpatient procedure" ;
label var pclass_ip8               "Procedure class 8 for inpatient procedure" ;
label var pclass_ip9               "Procedure class 9 for inpatient procedure" ;
label var prccs_ip1                "CCS: principal procedure from inpatient discharge record" ;
label var prccs_ip2                "CCS: procedure 2 from inpatient discharge record" ;
label var prccs_ip3                "CCS: procedure 3 from inpatient discharge record" ;
label var prccs_ip4                "CCS: procedure 4 from inpatient discharge record" ;
label var prccs_ip5                "CCS: procedure 5 from inpatient discharge record" ;
label var prccs_ip6                "CCS: procedure 6 from inpatient discharge record" ;
label var prccs_ip7                "CCS: procedure 7 from inpatient discharge record" ;
label var prccs_ip8                "CCS: procedure 8 from inpatient discharge record" ;
label var prccs_ip9                "CCS: procedure 9 from inpatient discharge record" ;
label var prver                    "Procedure Version" ;
label var pr_ip1                   "Principal procedure from inpatient discharge record" ;
label var pr_ip2                   "Procedure 2 from inpatient discharge record" ;
label var pr_ip3                   "Procedure 3 from inpatient discharge record" ;
label var pr_ip4                   "Procedure 4 from inpatient discharge record" ;
label var pr_ip5                   "Procedure 5 from inpatient discharge record" ;
label var pr_ip6                   "Procedure 6 from inpatient discharge record" ;
label var pr_ip7                   "Procedure 7 from inpatient discharge record" ;
label var pr_ip8                   "Procedure 8 from inpatient discharge record" ;
label var pr_ip9                   "Procedure 9 from inpatient discharge record" ;
label var totchg_ip                "Total charge for ED and inpatient services" ;

/* Convert special values to missing values */
recode chron1                    (-99 -88 -66=.) ;
recode chron2                    (-99 -88 -66=.) ;
recode chron3                    (-99 -88 -66=.) ;
recode chron4                    (-99 -88 -66=.) ;
recode chron5                    (-99 -88 -66=.) ;
recode chron6                    (-99 -88 -66=.) ;
recode chron7                    (-99 -88 -66=.) ;
recode chron8                    (-99 -88 -66=.) ;
recode chron9                    (-99 -88 -66=.) ;
recode chron10                   (-99 -88 -66=.) ;
recode chron11                   (-99 -88 -66=.) ;
recode chron12                   (-99 -88 -66=.) ;
recode chron13                   (-99 -88 -66=.) ;
recode chron14                   (-99 -88 -66=.) ;
recode chron15                   (-99 -88 -66=.) ;
recode chron16                   (-99 -88 -66=.) ;
recode chron17                   (-99 -88 -66=.) ;
recode chron18                   (-99 -88 -66=.) ;
recode chron19                   (-99 -88 -66=.) ;
recode chron20                   (-99 -88 -66=.) ;
recode chron21                   (-99 -88 -66=.) ;
recode chron22                   (-99 -88 -66=.) ;
recode chron23                   (-99 -88 -66=.) ;
recode chron24                   (-99 -88 -66=.) ;
recode chron25                   (-99 -88 -66=.) ;
recode chron26                   (-99 -88 -66=.) ;
recode chron27                   (-99 -88 -66=.) ;
recode chron28                   (-99 -88 -66=.) ;
recode chron29                   (-99 -88 -66=.) ;
recode chron30                   (-99 -88 -66=.) ;
recode disp_ip                   (-9 -8 -6 -5=.) ;
recode drg                       (-99 -88 -66=.) ;
recode drgver                    (-9 -8 -6 -5=.) ;
recode drg_nopoa                 (-99 -88 -66=.) ;
recode dxccs1                    (-999 -888 -666=.) ;
recode dxccs2                    (-999 -888 -666=.) ;
recode dxccs3                    (-999 -888 -666=.) ;
recode dxccs4                    (-999 -888 -666=.) ;
recode dxccs5                    (-999 -888 -666=.) ;
recode dxccs6                    (-999 -888 -666=.) ;
recode dxccs7                    (-999 -888 -666=.) ;
recode dxccs8                    (-999 -888 -666=.) ;
recode dxccs9                    (-999 -888 -666=.) ;
recode dxccs10                   (-999 -888 -666=.) ;
recode dxccs11                   (-999 -888 -666=.) ;
recode dxccs12                   (-999 -888 -666=.) ;
recode dxccs13                   (-999 -888 -666=.) ;
recode dxccs14                   (-999 -888 -666=.) ;
recode dxccs15                   (-999 -888 -666=.) ;
recode dxccs16                   (-999 -888 -666=.) ;
recode dxccs17                   (-999 -888 -666=.) ;
recode dxccs18                   (-999 -888 -666=.) ;
recode dxccs19                   (-999 -888 -666=.) ;
recode dxccs20                   (-999 -888 -666=.) ;
recode dxccs21                   (-999 -888 -666=.) ;
recode dxccs22                   (-999 -888 -666=.) ;
recode dxccs23                   (-999 -888 -666=.) ;
recode dxccs24                   (-999 -888 -666=.) ;
recode dxccs25                   (-999 -888 -666=.) ;
recode dxccs26                   (-999 -888 -666=.) ;
recode dxccs27                   (-999 -888 -666=.) ;
recode dxccs28                   (-999 -888 -666=.) ;
recode dxccs29                   (-999 -888 -666=.) ;
recode dxccs30                   (-999 -888 -666=.) ;
recode dxver                     (-9 -8 -6 -5=.) ;
recode e_ccs1                    (-999 -888 -666=.) ;
recode e_ccs2                    (-999 -888 -666=.) ;
recode e_ccs3                    (-999 -888 -666=.) ;
recode e_ccs4                    (-999 -888 -666=.) ;
recode hosp_ed                   (-9999 -8888 -6666=.) ;
recode injury                    (-9 -8 -6 -5=.) ;
recode injury_cut                (-9 -8 -6 -5=.) ;
recode injury_drown              (-9 -8 -6 -5=.) ;
recode injury_fall               (-9 -8 -6 -5=.) ;
recode injury_fire               (-9 -8 -6 -5=.) ;
recode injury_firearm            (-9 -8 -6 -5=.) ;
recode injury_machinery          (-9 -8 -6 -5=.) ;
recode injury_mvt                (-9 -8 -6 -5=.) ;
recode injury_nature             (-9 -8 -6 -5=.) ;
recode injury_poison             (-9 -8 -6 -5=.) ;
recode injury_severity           (-9 -8 -6 -5=.) ;
recode injury_struck             (-9 -8 -6 -5=.) ;
recode injury_suffocation        (-9 -8 -6 -5=.) ;
recode intent_assault            (-9 -8 -6 -5=.) ;
recode intent_self_harm          (-9 -8 -6 -5=.) ;
recode intent_unintentional      (-9 -8 -6 -5=.) ;
recode key_ed                    (-999999999999999 -888888888888888 -666666666666666=.) ;
recode los_ip                    (-9999 -8888 -6666=.) ;
recode mdc                       (-9 -8 -6 -5=.) ;
recode mdc_nopoa                 (-9 -8 -6 -5=.) ;
recode multinjury                (-9 -8 -6 -5=.) ;
recode ndx                       (-99 -88 -66=.) ;
recode necode                    (-99 -88 -66=.) ;
recode npr_ip                    (-99 -88 -66=.) ;
recode pclass_ip1                (-99 -88 -66=.) ;
recode pclass_ip2                (-99 -88 -66=.) ;
recode pclass_ip3                (-99 -88 -66=.) ;
recode pclass_ip4                (-99 -88 -66=.) ;
recode pclass_ip5                (-99 -88 -66=.) ;
recode pclass_ip6                (-99 -88 -66=.) ;
recode pclass_ip7                (-99 -88 -66=.) ;
recode pclass_ip8                (-99 -88 -66=.) ;
recode pclass_ip9                (-99 -88 -66=.) ;
recode prccs_ip1                 (-99 -88 -66=.) ;
recode prccs_ip2                 (-99 -88 -66=.) ;
recode prccs_ip3                 (-99 -88 -66=.) ;
recode prccs_ip4                 (-99 -88 -66=.) ;
recode prccs_ip5                 (-99 -88 -66=.) ;
recode prccs_ip6                 (-99 -88 -66=.) ;
recode prccs_ip7                 (-99 -88 -66=.) ;
recode prccs_ip8                 (-99 -88 -66=.) ;
recode prccs_ip9                 (-99 -88 -66=.) ;
recode prver                     (-9 -8 -6 -5=.) ;
recode totchg_ip                 (-99999999.99 -88888888.88 -66666666.66=.) ;

describe;

save "NEDS_2015Q1Q3_IP.dta", replace;
#delimit cr
